@@ -3,7 +3,7 @@
 Class to manage icons and allow the user to provide substitutions based
 on the the system theme.
 
-Copyright (C) 2015-2019
+Copyright (C) 2015-2022
 by: Andrew J. Bibb
 License: MIT
 
@@ -40,41 +40,46 @@ DEALINGS IN THE SOFTWARE.
 
 struct IconElement
 {
-	QString resource_path;
-	QString colorize;
-	QString fdo_name;
-	QStringList theme_names;
+   QString resource_path;
+   QString colorize;
+   QString fdo_name;
+   QStringList theme_names;
 };
 
 class IconManager : public QObject
 {
   Q_OBJECT
 
-  public:
-  // members
+   public:
+   // members
     IconManager(QObject* parent);
-    
-  // functions
-		QIcon getIcon(const QString&);
-		QString getIconName(const QString&);
-		inline void setIconColor(const QColor& col) {icon_color = col;}
-  
-  private:
-  // members
-		QMap<QString, IconElement> icon_map; 
-		QString cfg;
-		QString qrc;
-		QColor icon_color;
-		
-	// functions
-		bool buildResourceIcon(QIcon&, const QString&, const QString&);
-		bool buildThemeIcon(QIcon&, const QString&);	
-		QString getFallback(const QString&);
-		void makeLocalFile();	
-		QString extractValue(const QString&);
-		QString extractKey(const QString&);
-		QPixmap processArt(const QString&, const QColor&);
-		QString findQualifiedName(const QString&, const QStringList& = QStringList() );
-  
+
+   // functions
+      QIcon getIcon(const QString&);
+      QString getIconName(const QString&);
+      QStringList getInstalledIconThemes();
+      inline void setIconColor(const QColor& col) {icon_color = col;}
+
+   private:
+   // members
+      QMap<QString, IconElement> icon_map;
+      QMap<QString,QIcon> cached_icons;
+      QMap<QString,QString> foundlist;
+      QStringList notfoundlist;
+      QString cfg;
+      QString qrc;
+      QColor icon_color;
+
+   // functions
+      bool buildResourceIcon(QIcon&, const QString&, const QString&);
+      bool buildFdoIcon(QIcon&, const QString&);
+      QString getFallback(const QString&);
+      void makeLocalFile();
+      QString extractValue(const QString&);
+      QString extractKey(const QString&);
+      QPixmap processArt(const QString&, const QColor&);
+      QString findQualifiedName(const QString&, const QStringList& = QStringList() );
+
 };
+
 #endif
