@@ -2,28 +2,28 @@
 
 Code to manage the Provisioning Editor dialog.
 
-Copyright (C) 2013-2019
+Copyright (C) 2013-2022
 by: Andrew J. Bibb
-License: MIT 
+License: MIT
 
-Permission is hereby granted, free of charge, to any person obtaining a copy 
-of this software and associated documentation files (the "Software"),to deal 
-in the Software without restriction, including without limitation the rights 
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
-copies of the Software, and to permit persons to whom the Software is 
-furnished to do so, subject to the following conditions: 
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"),to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
 
-The above copyright notice and this permission notice shall be included 
+The above copyright notice and this permission notice shall be included
 in all copies or substantial portions of the Software.
 
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
-***********************************************************************/ 
+***********************************************************************/
 
 # ifndef PROVISIONING_EDITOR_H
 # define PROVISIONING_EDITOR_H
@@ -47,9 +47,9 @@ class ProvisioningEditor : public QDialog
   Q_OBJECT
 
   public:
-    ProvisioningEditor(QWidget*);
-    
-  private:  
+    ProvisioningEditor(QWidget*, const float&);
+
+  private:
   // members
     Ui::Provisioning ui;
     int i_sel;
@@ -63,20 +63,18 @@ class ProvisioningEditor : public QDialog
     QActionGroup* group_combobox;
     QActionGroup* group_validated;
     QActionGroup* group_selectfile;
-    QActionGroup* group_ipv4;
-    QActionGroup* group_ipv6;
     QButtonGroup* bg01;
     QStatusBar* statusbar;
     int statustimeout;
     QString con_path;
-    
+
   private slots:
     void inputSelectFile(QAction*);
     void inputValidated(QAction*);
     void inputComboBox(QAction*);
     void inputFreeForm(QAction*);
-    void ipv4Triggered(QAction*);
-    void ipv6Triggered(QAction*);
+    void ipv4Address();
+    void ipv6Address();
     void templateTriggered(QAction*);
     void showWhatsThis();
     void resetPage();
@@ -86,9 +84,11 @@ class ProvisioningEditor : public QDialog
     void deleteCompleted(bool);
     void writeCompleted(qint64);
     void callbackErrorHandler(QDBusError);
-        
+
   public:
     inline void setWhatsThisIcon(QIcon icon) {ui.toolButton_whatsthis->setIcon(icon);}
+    inline void setIconSize (float sz) {ui.toolButton_whatsthis->setIconSize(ui.toolButton_whatsthis->icon().actualSize(QSize(16,16) *= sz) ); }
+
 };
 
 
