@@ -2,7 +2,7 @@
 /**************************** shared.h ***************************
 Functions shared across various classes
 
-Copyright (C) 2013-2019
+Copyright (C) 2013-2022
 by: Andrew J. Bibb
 License: MIT
 
@@ -37,6 +37,8 @@ DEALINGS IN THE SOFTWARE.
 # include <QLineEdit>
 # include <QLabel>
 # include <QPushButton>
+# include <QValidator>
+# include <QDBusInterface>
 
 namespace shared {
 //
@@ -44,30 +46,32 @@ namespace shared {
 class ValidatingDialog : public QDialog
 {
   Q_OBJECT
-  
+
   public:
     ValidatingDialog(QWidget*);
     inline void setLabel(const QString& s) {label->setText(s);}
+    static QString getPattern(const int&, bool plural = false);
     void setValidator(const int&, bool plural = false);
     inline QString getText() {return lineedit->text().trimmed();}
     inline void setText(const QString& s) {lineedit->setText(s);}
     inline void clear() {initialize();}
     inline bool isPlural() {return plural;}
-    
+
   private slots:
 		void textChanged();
 		void initialize();
-  
-  private:  
+
+  private:
     // members
     QLabel* label;
     QLineEdit* lineedit;
     QDialogButtonBox* buttonbox;
     bool plural;
-};
+}; // class
 
 QDBusMessage::MessageType processReply(const QDBusMessage& reply);
 bool extractMapData(QMap<QString,QVariant>&,const QVariant&);
 
-}
+
+} // namespace
 #endif
