@@ -4,7 +4,7 @@ Class to manage and present strings that need to be translated. These
 are typically not inline strings, rather strings used globally or strings
 returned by third parties, for instance, Connman.
 
-Copyright (C) 2013-2019
+Copyright (C) 2013-2022
 by: Andrew J. Bibb
 License: MIT
 
@@ -34,17 +34,17 @@ DEALINGS IN THE SOFTWARE.
 // Constructor
 TranslateStrings::TranslateStrings(QObject* parent) : QObject(parent) 
 {
-	// The stringlist is not actually used for anything other than a means
-	// to mark strings for translation.  
-	QStringList sl;
-	sl.clear();
+// The stringlist is not actually used for anything other than a means
+// to mark strings for translation.  
+  QStringList sl;
+  sl.clear();
 	
-	// Global strings
-	sl << tr("connman system tray", "Main Window Title");
-	sl << tr("cmst", "Abbreviated Program Name - used for QMessageBox titles");
+// Global strings
+  sl << tr("connman system tray", "Main Window Title");
+  sl << tr("cmst", "Abbreviated Program Name - used for QMessageBox titles");
 	
-	// Connman strings
-	sl << tr("idle", "connman state string");
+// Connman strings
+  sl << tr("idle", "connman state string");
   sl << tr("association", "connman state string");
   sl << tr("configuration", "connman state string");
   sl << tr("ready", "connman state string");
@@ -73,6 +73,7 @@ TranslateStrings::TranslateStrings(QObject* parent) : QObject(parent)
   sl << tr("none", "connman security string");
   sl << tr("wep", "connman security string");
   sl << tr("wps", "connman security string");
+  sl << tr("wps_advertising", "connman security string");
   
   sl << tr("Invalid arguments", "connman error string");
   sl << tr("Permission denied", "connman error string");
@@ -106,6 +107,7 @@ TranslateStrings::TranslateStrings(QObject* parent) : QObject(parent)
   sl << tr("manual", "connman ipv4 method string");
   sl << tr("off", "connman ipv4 method string");
   sl << tr("fixed", "connman ipv4 method string");
+  sl << tr("address", "connamn ipv4 method string");
   
   sl << tr("auto", "connman ipv6 method string");
   sl << tr("manual", "connman ipv6 method string");
@@ -117,8 +119,11 @@ TranslateStrings::TranslateStrings(QObject* parent) : QObject(parent)
   sl << tr("vpnc", "connman vpn connection type");
   sl << tr("l2tp", "connman vpn connection type");
   sl << tr("pptp", "connman vpn connection type");
+  sl << tr("wireguard", "connman vpn connection type");
+
+  sl << tr("true", "connman mdns setting");
+  sl << tr("false", "connman mdns setting");
   
-  	
 	return;
 }
 
@@ -126,12 +131,12 @@ TranslateStrings::TranslateStrings(QObject* parent) : QObject(parent)
 // Function to return a stringlist with entries translated
 QStringList TranslateStrings::cmtr_sl(const QStringList& sl_src)
 {
-	QStringList sl_rtn;
-	sl_rtn.clear();
-	for (int i = 0; i < sl_src.count(); ++i) {
-		sl_rtn << TranslateStrings::cmtr(sl_src.at(i) );
-	}
+  QStringList sl_rtn;
+  sl_rtn.clear();
+  for (int i = 0; i < sl_src.count(); ++i) {
+	  sl_rtn << TranslateStrings::cmtr(sl_src.at(i) );
+  }
 
-	return sl_rtn;
+  return sl_rtn;
 }
 
