@@ -2,28 +2,28 @@
 
 Code to manage the VPN Provisioning Editor dialog.
 
-Copyright (C) 2016-2019
+Copyright (C) 2016-2022
 by: Andrew J. Bibb
-License: MIT 
+License: MIT
 
-Permission is hereby granted, free of charge, to any person obtaining a copy 
-of this software and associated documentation files (the "Software"),to deal 
-in the Software without restriction, including without limitation the rights 
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
-copies of the Software, and to permit persons to whom the Software is 
-furnished to do so, subject to the following conditions: 
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"),to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
 
-The above copyright notice and this permission notice shall be included 
+The above copyright notice and this permission notice shall be included
 in all copies or substantial portions of the Software.
 
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
-***********************************************************************/ 
+***********************************************************************/
 
 # ifndef VPN_PROVISIONING_EDITOR_H
 # define VPN_PROVISIONING_EDITOR_H
@@ -50,9 +50,9 @@ class VPN_Editor : public QDialog
   Q_OBJECT
 
   public:
-    VPN_Editor(QWidget*);
-    
-  private:  
+    VPN_Editor(QWidget*, const float&);
+
+  private:
   // members
     Ui::VPN_Prov ui;
     int i_sel;
@@ -63,6 +63,7 @@ class VPN_Editor : public QDialog
     QMenu* menu_VPNC;
     QMenu* menu_L2TP;
     QMenu* menu_PPTP;
+    QMenu* menu_WireGuard;
     QActionGroup* group_provider;
     QActionGroup* group_freeform;
     QActionGroup* group_combobox;
@@ -73,8 +74,7 @@ class VPN_Editor : public QDialog
     QButtonGroup* bg01;
     QStatusBar* statusbar;
     int statustimeout;
-    QString vpn_path;
-    
+
   private slots:
     void inputSelectFile(QAction*);
     void inputValidated(QAction*, QString s = QString());
@@ -91,9 +91,10 @@ class VPN_Editor : public QDialog
     void callbackErrorHandler(QDBusError);
     void createProvider(QAction*);
     void importOpenVPN();
-        
+
   public:
     inline void setWhatsThisIcon(QIcon icon) {ui.toolButton_whatsthis->setIcon(icon);}
+    inline void setIconSize (float sz) {ui.toolButton_whatsthis->setIconSize(ui.toolButton_whatsthis->icon().actualSize(QSize(16,16) *= sz) ); }
 };
 
 
